SymbolTable

Struct SymbolTable 

pub struct SymbolTable { /* private fields */ }
A set of strings. Unlike a regular set, strings are stored contiguously in pages to reduce memory usage.

Implementations

Source

impl SymbolTable

pub fn new() -> Self

Create an empty table.

Unlike many types in alloc, this allocates right away.

pub fn intern(&self, text: impl Into<String> + AsRef<str>) -> Symbol<'_>

Adds a symbol to the table if it does not exist.

Example
let table = SymbolTable::new();
assert_eq!(table.intern("my symbol"), table.intern("my symbol"));
pub fn gensym(&self, text: impl Into<String> + AsRef<str>) -> Symbol<'_>

Adds a symbol to the table. This symbol is always considered distinct from all other symbols even if they are textually identical.

Example
let table = SymbolTable::new();
assert_ne!(table.intern("my symbol"), table.gensym("my symbol"));
Name

The name “gensym” is common within the Lisp family of languages where symbols are built in the language itself.